Changelog
=========

0.0.2 (2025-03-14)
------------------

- switched to underscores in project name
- added placeholder support to: `from-pdf` and `to-pdf`


0.0.1 (2024-07-02)
------------------

- initial release

